@@ -1,6 +1,6 @@
 package DBM::Deep::Storage::DBI;
 
-use 5.006_000;
+use 5.008_004;
 
 use strict;
 use warnings FATAL => 'all';
@@ -57,7 +57,7 @@ sub open {
     ) or die $DBI::error;
 
     # Should we use the same method as done in new() if passed a $dbh?
-    (undef, $self->{driver}) = map lc, DBI->parse_dsn( $self->{dbi}{dsn} );
+    (undef, $self->{driver}) = map defined($_) ? lc($_) : undef, DBI->parse_dsn( $self->{dbi}{dsn} );
 
     return 1;
 }
